Inspection
=============================================

The ``pyterrier_alpha.inspect`` module provides a way to inspect PyTerrier ``Transformer``
and ``Artifact`` objects.

.. autofunction:: pyterrier_alpha.inspect.artifact_type_format

.. autofunction:: pyterrier_alpha.inspect.transformer_outputs

.. autoexception:: pyterrier_alpha.inspect.InspectError
